import request from '@/axios'
import { REQUEST_BASE } from '@/constants'
import { categoryData, goodsData } from './types'
import { productDataParse } from './parseData'
export const getProductCategory = (params: {
  page?: number
  limit?: number
  pid: number
}): Promise<IResponse> => {
  return request.get({ url: `${REQUEST_BASE}/productCategory/index`, params })
}
export const addProductCategory = (data: categoryData): Promise<IResponse> => {
  return request.post({ url: `${REQUEST_BASE}/productCategory/save`, data })
}
export const delProductCategory = (id: number): Promise<IResponse> => {
  return request.post({ url: `${REQUEST_BASE}/productCategory/delete/${id}` })
}
export const putProductCategory = (data: categoryData): Promise<IResponse> => {
  return request.post({ url: `${REQUEST_BASE}/productCategory/update/${data.id}`, data })
}
export const getProduct = (params: { page?: number; limit?: number }): Promise<IResponse> => {
  return request.get({ url: `${REQUEST_BASE}/product/index`, params })
}
export const addProduct = (data: goodsData): Promise<IResponse> => {
  const pushData = productDataParse(data)
  return request.post({ url: `${REQUEST_BASE}/product/save`, data: pushData })
}
export const delProduct = (id: number): Promise<IResponse> => {
  return request.post({ url: `${REQUEST_BASE}/product/delete/${id}` })
}
export const putProduct = (data: goodsData): Promise<IResponse> => {
  const pushData = productDataParse(data)
  return request.post({ url: `${REQUEST_BASE}/product/update/${data.id}`, data: pushData })
}
export const getProductDetail = (
  id: any
): Promise<
  IResponse<{
    storeInfo: any
    productValue: any[]
  }>
> => {
  return request.get({
    url: `${REQUEST_BASE}/product/read/${id}`
  })
}
